@@ -1,5 +1,6 @@
 import os
 import sys
+import time
 
 import logbook
 from logbook import StreamHandler
@@ -135,12 +136,13 @@ def run_logs():
 if not HAS_RUN:
     if not APPDATA_FOLDER.joinpath("config.ini").exists():
         logbook.warning(
-            "Config.ini should exist in '{APPDATA_FOLDER}', in a future update this will be a requirement.".format(
-                APPDATA_FOLDER=APPDATA_FOLDER
-            )
+            "Config.ini should exist in '{APPDATA_FOLDER}', in a future update this will be a requirement.",
+            APPDATA_FOLDER=APPDATA_FOLDER,
         )
+        time.sleep(5)
     if COPIED_TO_NEW_DIR:
         logbook.warning(
-            "Config.ini new location is {APPDATA_FOLDER}".format(APPDATA_FOLDER=APPDATA_FOLDER)
+            "Config.ini new location is {APPDATA_FOLDER}", APPDATA_FOLDER=APPDATA_FOLDER
         )
+        time.sleep(5)
     run_logs()
